diff libpurple/idle.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 516f14bef90e
line wrap: on
line diff
--- a/libpurple/idle.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/idle.h	Mon Mar 19 07:01:17 2007 +0000
@@ -2,9 +2,9 @@
  * @file idle.h Idle API
  * @ingroup core
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -22,8 +22,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#ifndef _GAIM_IDLE_H_
-#define _GAIM_IDLE_H_
+#ifndef _PURPLE_IDLE_H_
+#define _PURPLE_IDLE_H_
 
 /**
  * Idle UI operations.
@@ -31,7 +31,7 @@
 typedef struct
 {
 	time_t (*get_time_idle)(void);
-} GaimIdleUiOps;
+} PurpleIdleUiOps;
 
 #ifdef __cplusplus
 extern "C" {
@@ -47,14 +47,14 @@
  * 'active'.  The conversation code calls this when the
  * user sends an IM, for example.
  */
-void gaim_idle_touch(void);
+void purple_idle_touch(void);
 
 /**
  * Fake our idle time by setting the time at which our
  * accounts purportedly became idle.  This is used by
  * the I'dle Mak'er plugin.
  */
-void gaim_idle_set(time_t time);
+void purple_idle_set(time_t time);
 
 /*@}*/
 
@@ -68,24 +68,24 @@
  *
  * @param ops The UI operations structure.
  */
-void gaim_idle_set_ui_ops(GaimIdleUiOps *ops);
+void purple_idle_set_ui_ops(PurpleIdleUiOps *ops);
 
 /**
  * Returns the UI operations structure used for idle reporting.
  *
  * @return The UI operations structure in use.
  */
-GaimIdleUiOps *gaim_idle_get_ui_ops(void);
+PurpleIdleUiOps *purple_idle_get_ui_ops(void);
 
 /**
  * Initializes the idle system.
  */
-void gaim_idle_init(void);
+void purple_idle_init(void);
 
 /**
  * Uninitializes the idle system.
  */
-void gaim_idle_uninit(void);
+void purple_idle_uninit(void);
 
 /*@}*/
 
@@ -93,4 +93,4 @@
 }
 #endif
 
-#endif /* _GAIM_IDLE_H_ */
+#endif /* _PURPLE_IDLE_H_ */
@@ -2,9 +2,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.